@@ -1,3 +1,5 @@
+from kraken_html.html_field import Html_field
+
 
 class Html_table:
 
@@ -99,8 +101,6 @@ class Html_table:
         # Define link data. 
         record_type = value.get('@type', None)
         record_id = value.get('@id', None)
-        path = '/' + record_type + '/' + record_id
-
 
 
         content = ''
@@ -110,12 +110,16 @@ class Html_table:
         for i in keys:
             cell_value = value.get(i, None)
 
-            # Add link
-            if i in ['@id', 'schema:name'] and record_type and record_id:
-                content += self._table_body_cell_link(cell_value, path)
+            html_field = Html_field()
+            i_value = html_field.get(record_type, record_id, i, cell_value)
+
+            content += self._table_body_cell(i_value)
+
+
+            # Add link if U
+
+
 
-            else:
-                content += self._table_body_cell(cell_value)
 
         content += '</tr>'
 
@@ -131,13 +135,6 @@ class Html_table:
         return content
 
 
-    def _table_body_cell_link(self, value, link):
-        
-        content = '<td><a href="{link}">{value}</a></td>'.format(value=value, link=link)
-
-        return content
-
-
     def _table_body_close(self):
 
         content = '</tbody>'
