@@ -43,6 +43,17 @@ class Kraken_html:
         return html_record.record(keys, value)
 
 
+    def record_detail(self, value):
+
+
+        html_record = Html_record()
+
+        keys = self._get_keys(value)
+
+
+        return html_record.record_detail(keys, value)
+
+
 
 
     def form(self, value):
